==> kube-integration-1.3.5.tgz: package/server/api/kube-native/releases/controller.js <==
'use strict';

const _                          = require('lodash');
const Promise                    = require('bluebird');
const logger                     = require('cf-logs');
const ResponseHandler            = require('./../../../helpers/ResponseHandler');
const BaseCrudController         = require('./../../crud.base.controller');


class Controller extends BaseCrudController {
    constructor() {
        super({
            lookForNamespaces: true
        });
    }

    compareRevisionsInRelease(req, res, next){
        const kubeManager        = req.kubeManager;
        const releaseController   = kubeManager.getReleaseController.bind(kubeManager);
        const namespace = req.query.tillerNamespace || 'kube-system'; // default for tiller
        const releaseName = req.params.release;
        const base = req.params.base;
        const head = req.params.head;
        releaseController(namespace).compareRevisionsInRelease(releaseName, base, head)
        .then((data) => {
            res.send(data);
        })
        .catch(next);
    }

    getChartDataForType(type){
        return function(req, res, next){
            const kubeManager        = req. kubeManager;
            const releaseController   = kubeManager.getReleaseController.bind(kubeManager);
            const namespace = req.query.tillerNamespace || 'kube-system'; // default for tiller
            const releaseName = req.params.release;
            const revision = req.params.revision;
            const operationName = _.camelCase(`get chart ${type} for revision`);
            releaseController(namespace)[operationName](releaseName, revision)
            .then((data) => {
                res.send(data);
            })
            .catch(next);
        };
    }
}

module.exports = new Controller();

==> kube-integration-1.3.23.tgz: package/server/api/kube-native/releases/controller.js <==
'use strict';

const _                          = require('lodash');
const Promise                    = require('bluebird');
const logger                     = require('cf-logs');
const ResponseHandler            = require('./../../../helpers/ResponseHandler');
const BaseCrudController         = require('./../../crud.base.controller');


class Controller extends BaseCrudController {
    constructor() {
        super({
            lookForNamespaces: true
        });
    }

    compareRevisionsInRelease(req, res, next){
        const kubeManager        = req.kubeManager;
        const releaseController   = kubeManager.getReleaseController.bind(kubeManager);
        const namespace = req.query.namespace || 'kube-system'; // default for tiller
        const releaseName = req.params.release;
        const base = req.params.base;
        const head = req.params.head;
        releaseController(namespace).compareRevisionsInRelease(releaseName, base, head)
        .then((data) => {
            res.send(data);
        })
        .catch(next);
    }

    getChartDataForType(type){
        return function(req, res, next){
            const kubeManager        = req. kubeManager;
            const releaseController   = kubeManager.getReleaseController.bind(kubeManager);
            const namespace = req.query.namespace || 'kube-system'; // default for tiller
            const releaseName = req.params.release;
            const revision = req.params.revision;
            const operationName = _.camelCase(`get chart ${type} for revision`);
            releaseController(namespace)[operationName](releaseName, revision)
            .then((data) => {
                res.send(data);
            })
            .catch(next);
        };
    }
}

module.exports = new Controller();
